@@ -1,7 +1,6 @@
 ;;; biblio.scm  --  Bibliography functions.
-;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2005, 2006, 2007, 2009, 2013, 2018  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2007, 2009, 2013, 2018, 2020  Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright 2001, 2002, 2003, 2004  Manuel Serrano
 ;;; Copyright 2003, 2004  Erick Gallesio - I3S-CNRS/ESSI <eg@essi.fr>
 ;;;
@@ -23,24 +22,24 @@
 
 
 (define-module (skribilo biblio)
-  :use-module (skribilo utils syntax) ;; `when', `unless'
+  #:use-module (skribilo utils syntax) ;; `when', `unless'
 
-  :use-module (srfi srfi-1)
-  :autoload   (srfi srfi-34)         (raise)
-  :use-module (srfi srfi-35)
-  :use-module (srfi srfi-39)
-  :use-module (skribilo condition)
+  #:use-module (srfi srfi-1)
+  #:autoload   (srfi srfi-34)         (raise)
+  #:use-module (srfi srfi-35)
+  #:use-module (srfi srfi-39)
+  #:use-module (skribilo condition)
 
-  :autoload   (skribilo reader)       (*document-reader*)
-  :autoload   (skribilo parameters)   (*bib-path*)
-  :autoload   (skribilo ast)          (<markup> <handle> is-markup?)
-  :autoload   (skribilo lib)          (skribe-warning)
-  :autoload   (skribilo biblio author)(short-author-names)
+  #:autoload   (skribilo reader)       (*document-reader*)
+  #:use-module (skribilo parameters)
+  #:use-module (skribilo ast)
+  #:autoload   (skribilo lib)          (skribe-warning)
+  #:autoload   (skribilo biblio author)(short-author-names)
 
-  :use-module (ice-9 optargs)
-  :use-module (oop goops)
+  #:use-module (ice-9 optargs)
+  #:use-module (oop goops)
 
-  :export (bib-table? make-bib-table *bib-table*
+  #:export (bib-table? make-bib-table *bib-table*
 	   bib-add! bib-duplicate bib-for-each bib-map
 	   open-bib-file parse-bib
 
@@ -65,8 +64,6 @@
            biblio-template-error:template
            biblio-parse-error:sexp))
 
-;;; Author: Erick Gallesio, Manuel Serrano, Ludovic Courts
-;;;
 ;;; Commentary:
 ;;;
 ;;; Provides the bibliography data type and basic bibliography handling,
