@@ -1,7 +1,6 @@
 ;;; html.scm  --  HTML engine.
-;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2005, 2006, 2007, 2008, 2009, 2011, 2012, 2018  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2007, 2008, 2009, 2011, 2012, 2018, 2020  Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
 ;;;
 ;;;
@@ -21,32 +20,32 @@
 ;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo engine html)
-  :use-module (skribilo lib)
-  :use-module (skribilo ast)
-  :use-module (skribilo config)
-  :use-module (skribilo engine)
-  :use-module (skribilo writer)
-  :use-module (skribilo location)
-  :use-module (skribilo utils strings)
-  :use-module (skribilo utils syntax)
-  :use-module (skribilo package base)
-  :autoload   (skribilo utils images)  (convert-image)
-  :autoload   (skribilo utils files)   (file-prefix file-suffix)
-  :autoload   (skribilo parameters)    (*destination-file*)
-  :autoload   (skribilo evaluator)     (evaluate-document)
-  :autoload   (skribilo output)        (output)
-  :autoload   (skribilo debug)         (*debug*)
-  :autoload   (skribilo sui)           (document-sui)
-  :autoload   (ice-9 rdelim)           (read-line)
-  :autoload   (ice-9 regex)            (regexp-substitute/global)
-  :use-module (ice-9 match)
+  #:use-module (skribilo lib)
+  #:use-module (skribilo ast)
+  #:use-module (skribilo config)
+  #:use-module (skribilo engine)
+  #:use-module (skribilo writer)
+  #:use-module (skribilo location)
+  #:use-module (skribilo utils strings)
+  #:use-module (skribilo utils syntax)
+  #:use-module (skribilo package base)
+  #:autoload   (skribilo utils images)  (convert-image)
+  #:autoload   (skribilo utils files)   (file-prefix file-suffix)
+  #:autoload   (skribilo parameters)    (*destination-file*)
+  #:autoload   (skribilo evaluator)     (evaluate-document)
+  #:autoload   (skribilo output)        (output)
+  #:autoload   (skribilo debug)         (*debug*)
+  #:autoload   (skribilo sui)           (document-sui)
+  #:autoload   (ice-9 rdelim)           (read-line)
+  #:autoload   (ice-9 regex)            (regexp-substitute/global)
+  #:use-module (ice-9 match)
 
-  :use-module (srfi srfi-1)
-  :use-module (srfi srfi-13)
-  :use-module (srfi srfi-14)
-  :use-module (srfi srfi-39)
+  #:use-module (srfi srfi-1)
+  #:use-module (srfi srfi-13)
+  #:use-module (srfi srfi-14)
+  #:use-module (srfi srfi-39)
 
-  :export (html-engine html-title-engine html-file
+  #:export (html-engine html-title-engine html-file
            html-width html-class html-markup-class
            html-title-authors))
 
@@ -63,7 +62,7 @@
 (define unspecified?
   ;; XXX: Hack to recognize the unspecified value as understood by
   ;; `engine-custom' et al.
-  (let ((really-unspecified? unspecified?))
+  (let ((really-unspecified? (@ (guile) unspecified?)))
     (lambda (x)
       (or (really-unspecified? x)
           (eq? x 'unspecified)))))
@@ -1162,14 +1161,11 @@
 ;*---------------------------------------------------------------------*/
 (define (&html-generic-document n title e)
   (define (set-output-encoding)
-    (cond-expand
-     (guile-2
-      ;; Make sure the output is suitably encoded.
-      (and=> (engine-custom e 'charset)
-             (lambda (charset)
-               (set-port-encoding! (current-output-port) charset)
-               (set-port-conversion-strategy! (current-output-port) 'error))))
-     (else #t)))
+    ;; Make sure the output is suitably encoded.
+    (and=> (engine-custom e 'charset)
+           (lambda (charset)
+             (set-port-encoding! (current-output-port) charset)
+             (set-port-conversion-strategy! (current-output-port) 'error))))
 
    (let* ((id (markup-ident n))
 	  (header (new markup
