@@ -1,7 +1,6 @@
 ;;; info.scm  --  GNU Info engine.
-;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2008, 2009, 2012, 2015, 2018  Ludovic Courtès <ludo@gnu.org>
+;;; Copyright 2008, 2009, 2012, 2015, 2018, 2020  Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright 2001, 2002  Manuel Serrano
 ;;;
 ;;;
@@ -21,27 +20,26 @@
 ;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo engine info)
-  :use-module (skribilo lib)
-  :use-module (skribilo ast)
-  :use-module (skribilo engine)
-  :use-module (skribilo writer)
-  :use-module (skribilo utils syntax)
-  :use-module (skribilo package base)
-  :autoload   (skribilo parameters)    (*destination-file*)
-  :autoload   (skribilo output)        (output)
-  :autoload   (skribilo utils justify) (output-justified make-justifier
-                                        with-justification)
-  :autoload   (skribilo utils text-table) (table->ascii)
-  :autoload   (skribilo utils images)  (convert-image)
-  :autoload   (srfi srfi-1)            (fold)
-  :use-module (srfi srfi-8)
-  :use-module (srfi srfi-11)
-  :use-module (srfi srfi-13)
-  :use-module (srfi srfi-26)
-  :use-module (ice-9 match)
-  :use-module (ice-9 format)
+  #:use-module (skribilo lib)
+  #:use-module (skribilo ast)
+  #:use-module (skribilo engine)
+  #:use-module (skribilo writer)
+  #:use-module (skribilo utils syntax)
+  #:use-module (skribilo package base)
+  #:autoload   (skribilo parameters)    (*destination-file*)
+  #:use-module (skribilo output)
+  #:use-module (skribilo utils justify)
+  #:autoload   (skribilo utils text-table) (table->ascii)
+  #:autoload   (skribilo utils images)  (convert-image)
+  #:use-module (srfi srfi-1)
+  #:use-module (srfi srfi-8)
+  #:use-module (srfi srfi-11)
+  #:use-module (srfi srfi-13)
+  #:use-module (srfi srfi-26)
+  #:use-module (ice-9 match)
+  #:use-module (ice-9 format)
 
-  :export (info-engine))
+  #:export (info-engine))
 
 (skribilo-module-syntax)
 
@@ -85,7 +83,7 @@
 (define (info-node node next prev up)
    ;; info "(info) Expert Info"
    (print "\n")
-   (format #t "File: ~a,  Node: ~a,  ~:[~*~;Next: ~a,  ~]~:[~*~;Prev: ~a,  ~]Up: ~a~%"
+   (format #t "File: ~a,  Node: ~a,  ~:[~*~;Next: ~a,  ~]~:[~*~;Prev: ~a,  ~]Up: ~a~%~%"
            (info-dest) node next next prev prev up))
 
 ;*---------------------------------------------------------------------*/
@@ -145,18 +143,42 @@
                     children)))
     (newline)))
 
+(define (block-number n)
+  ;; Return the number of N, a chapter/section, as a string like "4.2.3.".
+  ;; Return #f if N or one of its parent nodes is unnumbered.
+  (let loop ((n n)
+             (numbers '()))
+    (cond ((not n)
+           (string-join (map number->string numbers) "."))
+          ((%block? n)
+           (let ((number (markup-option n :number)))
+             (and number
+                  (loop (ast-parent n) (cons number numbers)))))
+          (else
+           (loop (ast-parent n) numbers)))))
+
 ;*---------------------------------------------------------------------*/
 ;*    block-title ::%chapter ...                                       */
 ;*---------------------------------------------------------------------*/
-(define (block-title obj e)
+(define* (block-title obj e :key (number? #f))
+  (define number
+    (if number?
+        (lambda (title)
+          (let ((number (block-number obj)))
+            (if number
+                (string-append number ". " title)
+                title)))
+        (lambda (title)
+          title)))
+
   (or (let ((title (markup-option obj :info-node)))
-        (and title (ast->string title)))
+        (and title (number (ast->string title))))
       (let ((title    (markup-option obj :title))
             (subtitle (markup-option obj :subtitle)))
         (let ((title (if title title subtitle)))
-          (if (string? title)
-              title
-              (ast->string title))))))
+          (number (if (string? title)
+                      title
+                      (ast->string title)))))))
 
 ;*---------------------------------------------------------------------*/
 ;*    check-node-title-conflicts ...                                   */
@@ -191,10 +213,7 @@
   :options '(:title :author :ending)
   :action (lambda (doc e)
             (check-node-title-conflicts doc e)
-
-            (cond-expand
-             (guile-2 (set-port-encoding! (current-output-port) "UTF-8"))
-             (else #t))
+            (set-port-encoding! (current-output-port) "UTF-8")
 
             (let ((title     (markup-option doc :title))
                   (authors   (markup-option doc :author))
@@ -294,7 +313,17 @@
 	  (output-newline)
 	  (info-authors authors)
 	  (output-newline)
-	  (output-flush *margin*))))
+	  (output-flush (*margin*)))))
+
+   (let ((category (markup-option obj :info-dir-category))
+         (entry    (markup-option obj :info-dir-entry))
+         (name     (basename (info-dest) ".info")))
+     (when category
+       (format #t "INFO-DIR-SECTION ~a~%" category)
+       (format #t "START-INFO-DIR-ENTRY~%")
+       (format #t "* ~a: (~a).      ~a~%"
+               name name (or entry ""))
+       (format #t "END-INFO-DIR-ENTRY~%")))
 
    ;; the main node
    (receive (next prev top)
@@ -624,11 +653,11 @@
   :action (lambda (n e)
             (let ((body (markup-body n)))
               (output-newline)
-              (output-flush *margin*)
-              (let ((t (block-title n e)))
+              (output-flush (*margin*))
+              (let ((t (block-title n e :number? #t)))
                 (receive (next prev top)
                     (node-next+prev+up n e)
-                  (info-node t next prev top)
+                  (info-node (block-title n e) next prev top)
                   (print t)
                   (print (make-string (string-length t) #\=))))
               (node-menu n e)
@@ -643,11 +672,11 @@
   :options '(:title :info-node :number :toc :env :file)
   :action (lambda (n e)
             (let ((body (markup-body n)))
-              (output-flush *margin*)
-              (let ((t (block-title n e)))
+              (output-flush (*margin*))
+              (let ((t (block-title n e :number? #t)))
                 (receive (next prev top)
                     (node-next+prev+up n e)
-                  (info-node t next prev top)
+                  (info-node (block-title n e) next prev top)
                   (print t)
                   (print (make-string (string-length t) #\-))))
               (output body e))))
@@ -659,11 +688,11 @@
   :options '(:title :info-node :number :toc :env :file)
   :action (lambda (n e)
             (let ((body (markup-body n)))
-              (output-flush *margin*)
-              (let ((t (block-title n e)))
+              (output-flush (*margin*))
+              (let ((t (block-title n e :number? #t)))
                 (receive (next prev top)
                     (node-next+prev+up n e)
-                  (info-node t next prev top)
+                  (info-node (block-title n e) next prev top)
                   (print t)
                   (print (make-string (string-length t) #\~))))
               (output body e))))
@@ -673,10 +702,11 @@
 ;*---------------------------------------------------------------------*/
 (markup-writer 'paragraph info-engine
   :action (lambda (n e)
-            (output-newline)
-            (output-flush *margin*)
-            (or (first-paragraph? n)
-                (display "   "))
+            (unless (first-paragraph? n)
+              (output-newline))
+            (output-flush (*margin*))
+            (unless (first-paragraph? n)
+              (display "   "))
             (output (markup-body n) e)))
 
 ;*---------------------------------------------------------------------*/
@@ -687,11 +717,11 @@
   :action (lambda (n e)
             (let ((body (markup-body n)))
               (output-newline)
-              (output-flush *margin*)
-              (let ((t (block-title n e)))
+              (output-flush (*margin*))
+              (let ((t (block-title n e :number? #t)))
                 (receive (next prev top)
                     (node-next+prev+up n e)
-                  (info-node t next prev top)
+                  (info-node (block-title n e) next prev top)
                   (print t)
                   (print (make-string (string-length t) #\*))))
               (node-menu n e)
@@ -720,12 +750,12 @@
              :frame :rules :cellpadding :rulecolor)
   :action (lambda (n e)
             (let ((border (markup-option n :border)))
-              (output-flush *margin*)
+              (output-flush (*margin*))
               (if border
                   (border-table->info n)
                   (table->ascii n (lambda (obj)
                                     (output obj e))))
-              (output-flush *margin*))))
+              (output-flush (*margin*)))))
 
 ;*---------------------------------------------------------------------*/
 ;*    info ::&the-bibliography ...                                     */
@@ -781,12 +811,11 @@
   :action (lambda (n e)
             ;; Skip a line and indent the program.
             (newline)
-            (set! *margin* (+ 2 *margin*))
             (with-justification
              (make-justifier *text-column-width* 'verbatim)
              (lambda ()
-               (output (markup-body n) e)))
-            (set! *margin* (- *margin* 2))))
+               (output (markup-body n) e))
+             2)))
 
 (markup-writer '&prog-line info-engine
   :action (lambda (n e)
@@ -795,7 +824,7 @@
               (and (number? num)
                    (output-justified (format #f "~3d: " num))))
             (output (markup-body n) e)
-            (output-flush *margin*)))
+            (output-flush (*margin*))))
 
 ;*---------------------------------------------------------------------*/
 ;*    info ::%image ...                                                */
