@@ -1,8 +1,7 @@
 ;;; lncs.scm  --  The Skribilo style for LNCS articles.
-;;; -*- coding: iso-8859-1 -*-
 ;;;
 ;;; Copyright 2003, 2004  Manuel Serrano
-;;; Copyright 2007, 2015, 2018  Ludovic Courts <ludovic.courtes@laas.fr>
+;;; Copyright 2007, 2015, 2018, 2020  Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;;
 ;;; This file is part of Skribilo.
@@ -21,30 +20,31 @@
 ;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo package lncs)
-  :use-module (skribilo ast)
-  :use-module (skribilo engine)
-  :use-module (skribilo writer)
-  :autoload   (skribilo output)         (output)
-  :autoload   (skribilo package base)   (chapter font flush
-                                         toc the-bibliography)
-  :autoload   (skribilo utils keywords) (the-options the-body)
-  :autoload   (skribilo biblio template)(output-bib-entry-template
+  #:use-module (skribilo ast)
+  #:use-module (skribilo engine)
+  #:use-module (skribilo writer)
+  #:autoload   (skribilo output)         (output)
+  #:use-module (skribilo package base)
+  #:autoload   (skribilo utils keywords) (the-options the-body)
+  #:autoload   (skribilo biblio template)(output-bib-entry-template
                                          make-bib-entry-template/default)
-  :autoload   (skribilo biblio author)  (bib-sort/first-author-last-name)
-  :autoload   (skribilo evaluator)      (evaluate-document)
+  #:autoload   (skribilo biblio author)  (bib-sort/first-author-last-name
+                                          abbreviate-author-first-names/family-first
+                                          abbreviate-first-names)
+  #:autoload   (skribilo evaluator)      (evaluate-document)
 
-  :use-module (skribilo lib)
-  :use-module (skribilo utils syntax)
+  #:use-module (skribilo lib)
+  #:use-module (skribilo utils syntax)
 
-  :use-module (ice-9 optargs)
-  :use-module (srfi srfi-1)
-  :use-module (srfi srfi-13)
+  #:use-module (ice-9 optargs)
+  #:use-module (srfi srfi-1)
+  #:use-module (srfi srfi-13)
 
-  :export (abstract references))
+  #:export (abstract references))
 
 (skribilo-module-syntax)
 
-;;; Author: Manuel Serrano, Ludovic Courts
+;;; Author: Manuel Serrano, Ludovic Courtès
 ;;;
 ;;; Commentary:
 ;;;
